@@ -19,6 +19,7 @@ from agentbox.sandbox_async.sandbox_api import SandboxApi, SandboxInfo
 from agentbox.api.client.models import SandboxADB
 from agentbox.sandbox_async.filesystem_ssh.filesystem_ssh import SSHFilesystem
 from agentbox.sandbox_async.commands_ssh.command_ssh import SSHCommands
+from agentbox.sandbox_async.commands_ssh2.command_ssh2 import SSHCommands2
 
 logger = logging.getLogger(__name__)
 
@@ -149,14 +150,28 @@ class AsyncSandbox(SandboxSetup, SandboxApi):
 
         # 根据 sandbox id 进行区分 commands 类型
         if "brd" in self._sandbox_id.lower():
-            self._commands = SSHCommands(
+            # self._commands = SSHCommands(
+            #     self._ssh_host,
+            #     self._ssh_port,
+            #     self._ssh_username,
+            #     self._ssh_password,
+            #     self.connection_config,
+            # )
+            self._commands = SSHCommands2(
                 self._ssh_host,
                 self._ssh_port,
                 self._ssh_username,
                 self._ssh_password,
                 self.connection_config,
             )
-            self._watch_commands = SSHCommands(
+            # self._watch_commands = SSHCommands(
+            #     self._ssh_host,
+            #     self._ssh_port,
+            #     self._ssh_username,
+            #     self._ssh_password,
+            #     self.connection_config,
+            # )
+            self._watch_commands = SSHCommands2(
                 self._ssh_host,
                 self._ssh_port,
                 self._ssh_username,
@@ -507,7 +522,7 @@ class AsyncSandbox(SandboxSetup, SandboxApi):
         if request_timeout:
             config_dict["request_timeout"] = request_timeout
 
-        await SandboxApi._cls_kill(
+        return await SandboxApi._cls_kill(
             sandbox_id=self.sandbox_id,
             **config_dict,
         )
